diff --git a/tests/src/Functional/UwWcmsBasicTest.php b/tests/src/Functional/UwWcmsBasicTest.php
index eec1448f9fe675541c6ad7acb8b0e9e03a52a935..eff160aa822d48fd81fd9f711c8e2c9fda3f85f4 100644
--- a/tests/src/Functional/UwWcmsBasicTest.php
+++ b/tests/src/Functional/UwWcmsBasicTest.php
@@ -1133,22 +1133,22 @@ class UwWcmsBasicTest extends BrowserTestBase {
     $this->drupalLogin($this->drupalUsers['administrator']);
     // Test case 1:
     // Make sure manage fields of uw para fact figure
     // includes 'Small caption' with value 'small'.
     $this->drupalGet('admin/structure/paragraphs_type/uw_para_fact_figure/fields/paragraph.uw_para_fact_figure.field_uw_ff_info');
     $this->assertSession()->statusCodeEquals(200);
-    $smallcaption = $this->assertSession()->optionExists('default_value_input[field_uw_ff_info][0][style]', 'small');
-    $this->assertTrue($smallcaption);
-    $this->assertEquals('Small caption', $smallcaption->getText());
+    $smallhighlight = $this->assertSession()->optionExists('default_value_input[field_uw_ff_info][0][style]', 'small');
+    $this->assertTrue($smallhighlight);
+    $this->assertEquals('Small highlight', $smallhighlight->getText());
     // Test case 2:
     // Make sure adding facts and figures block, the config
     // block includes 'Small cation' with value 'small'.
     $this->drupalGet('node/1/layout');
     $this->assertSession()->statusCodeEquals(200);
     $this->clickLink('Add block');
     $this->clickLink('Facts and figures');
-    $smallcaption = $this->assertSession()->optionExists('settings[block_form][field_uw_ff_fact_figure][0][subform][field_uw_fact_figure][0][subform][field_uw_ff_info][0][style]', 'small');
-    $this->assertTrue($smallcaption);
-    $this->assertEquals('Small caption', $smallcaption->getText());
+    $smallhighlight = $this->assertSession()->optionExists('settings[block_form][field_uw_ff_fact_figure][0][subform][field_uw_fact_figure][0][subform][field_uw_ff_info][0][style]', 'small');
+    $this->assertTrue($smallhighlight);
+    $this->assertEquals('Small highlight', $smallhighlight->getText());
   }
 
   /**
@@ -1133,22 +1133,22 @@ class UwWcmsBasicTest extends BrowserTestBase {
     // Test case 1:
     // Make sure manage fields of uw para fact figure
-    // includes 'Small caption' with value 'small'.
+    // includes 'Small highlight' with value 'small'.
     $this->drupalGet('admin/structure/paragraphs_type/uw_para_fact_figure/fields/paragraph.uw_para_fact_figure.field_uw_ff_info');
     $this->assertSession()->statusCodeEquals(200);
@@ -1133,22 +1133,22 @@ class UwWcmsBasicTest extends BrowserTestBase {
     // Test case 2:
     // Make sure adding facts and figures block, the config
-    // block includes 'Small cation' with value 'small'.
+    // block includes 'Small highlight' with value 'small'.
     $this->drupalGet('node/1/layout');
     $this->assertSession()->statusCodeEquals(200);